==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/plugins/grepview/kdevgrepview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Allows fast searching of multiple files using patterns or regular expressions. And allow to replace it too.
Comment[bs]=Omogućava brzo pretraživanje više datoteka pomoću obrazaca i regularnim izrazima. I omogućava da ga zamjenu takođe.
Comment[ca]=Permet la cerca ràpida de múltiples fitxers usant patrons o expressions regulars. I també permet substitucions.
Comment[ca@valencia]=Permet la cerca ràpida de múltiples fitxers usant patrons o expressions regulars. I també permet substitucions.
Comment[da]=Muliggør hurtig søgning af flere filer med brug af mønstre eller regulære udtryk - og muliggør også erstatning.
Comment[de]=Ermöglicht es, Dateien mit Hilfe von Mustern und regulären Ausdrücken zu durchsuchen bzw. Ersetzungen vorzunehmen.
Comment[el]=Επιτρέπει γρήγορη αναζήτηση πολλών αρχείων με χρήση προτύπων ή κανονικών εκφράσεων. Επιτρέπει και την αντικατάστασή τους επίσης.
Comment[es]=Permite búsquedas rápidas de múltiples archivos usando patrones o expresiones regulares. También permite sustituciones.
Comment[et]=Lubab mustreid või regulaaravaldisi kasutades kiiresti paljudes failides teksti otsida, samuti asendada.
Comment[fi]=Mahdollistaa nopean useiden tiedostojen etsinnän käyttäen malleja tai säännöllisiä lausekkeita. Sallii myös korvauksen.
Comment[fr]=Permet la recherche rapide de fichiers multiples à l'aide de motifs ou d'expressions rationnelles, et d'effectuer le remplacement aussi.
Comment[ga]=Ceadaíonn sé duit il-comhaid a chuardach go tapa le patrúin nó sloinn ionadaíochta. Agus is féidir asáitiú chomh maith.
Comment[gl]=Permite facer unha procura rápida en varios ficheiros empregando padróns ou expresións regulares, e tamén realizar substitucións.
Comment[hu]=Lehetővé teszi több fájl gyors keresését minták és reguláris kifejezések használatával. És lehetővé teszi a cserét is.
Comment[it]=Consente la ricerca veloce di file multipli usando espressioni regolari o modelli. E consente anche di sostituirli.
Comment[kk]=Бірнеше файлда жәй не үлгі өрнегі бойынша тез іздеу мүмкіндігі. Қосымша ауыстыруға да болады.
Comment[nb]=Gjør raskt søk i flere filer mulig ved hjelp av mønstre eller regulære uttrykk. Og kan erstatte også.
Comment[nds]=Stellt gau Dörsöken vun mehr Dateien mit Söökmustern oder reguleer Utdrück praat. Utwesseln warrt ok ünnerstütt.
Comment[nl]=Staat toe snel te zoeken naar meerdere bestanden met gebruik van patronen of reguliere expressies. En staat ook vervanging toe.
Comment[pl]=Pozwala na szybkie znajdowanie wielu plików wykorzystując wzorce lub regularne wyrażenia. Pozwala także na ich zastępowanie.
Comment[pt]=Permite pesquisar rapidamente em vários ficheiros, usando padrões ou expressões regulares, permitindo também efectuar substituições.
Comment[pt_BR]=Permite pesquisar rapidamente em vários arquivos, usando padrões ou expressões regulares. E permite realizar substituições também.
Comment[ru]=Позволяет быстро искать (и заменять) текст по множеству файлов, применяя шаблоны поиска или регулярные выражения.
Comment[sk]=Umožní rýchle hľadanie viacerých súborov pomocou vzorov alebo regulárnych výrazov a umožní ich nahradiť.
Comment[sl]=Omogoča hitro iskanje po več datotekah, z uporabo vzorcev ali pa logičnih izrazov. Omogoča tudi zamenjave.
Comment[sv]=Tillåter snabb sökning i flera filer med mönster eller reguljära uttryck, och tillåter dessutom ersättning.
Comment[tr]=Desenleri ve düzenli ifadeleri kullanarak, birçok dosyada hızlı bir şekilde arama yapılmasını sağlar. Bul değiştir işlevini de yapar.
Comment[ug]=ئەندىزە ياكى مۇنتىزىم ئىپادە ئارقىلىق نۇرغۇن ھۆججەتلەردىن ئىزدەش ۋە ئالماشتۇرۇشقا ئىجازەت بېرىدۇ.
Comment[uk]=Надає можливості швидкого пошуку та заміни у декількох файлів на основі шаблонів або формальних виразів.
Comment[x-test]=xxAllows fast searching of multiple files using patterns or regular expressions. And allow to replace it too.xx
Comment[zh_CN]=可以用模式或正则表达式快速搜索多个文件，还可以替换。
Comment[zh_TW]=允許使用樣式或正規表示式來快速搜尋與取代多個檔案。
Name=Find/Replace In Files
Name[bs]=Nađi/zamijeni u datotekama
Name[ca]=Cerca i substitució en fitxers
Name[ca@valencia]=Cerca i substitució en fitxers
Name[cs]=Hledat-nahradit v souborech
Name[da]=Find/erstat i filer
Name[de]=In Dateien suchen/ersetzen
Name[el]=Αναζήτηση/Αντικατάσταση σε αρχεία
Name[en_GB]=Find/Replace In Files
Name[es]=Buscar/sustituir en archivos
Name[et]=Failides otsimine ja asendamine
Name[fi]=Etsi ja korvaa tiedostoista
Name[fr]=Chercher / Remplacer dans les fichiers
Name[gl]=Procurar/Substituír nos ficheiros
Name[hu]=Keresés/csere fájlokban
Name[it]=Trova/Sostituisci nei file
Name[kk]=Файлдарда іздеу/ауыстыру
Name[nb]=Finn/erstatt i filer
Name[nds]=Söken un Utwesseln in Dateien
Name[nl]=Zoeken/vervangen in bestanden
Name[pl]=Znajdź/zastąp w plikach
Name[pt]=Procurar/Substituir nos Ficheiros
Name[pt_BR]=Procurar/Substituir nos arquivos
Name[ru]=Поиск/замена в файлах
Name[sk]=Hľadať/nahradiť v súboroch
Name[sl]=Najdi/zamenjaj v datotekah
Name[sv]=Sök eller ersätt i filer
Name[tr]=Bu Dosyalarda Bul ve Değiştir
Name[ug]=ھۆججەت ئىچىدىن ئىزدەش/ئالماشتۇرۇش
Name[uk]=Пошук або заміна у файлах
Name[x-test]=xxFind/Replace In Filesxx
Name[zh_CN]=在文件中查找/替换
Name[zh_TW]=在檔案中尋找/取代
GenericName=Search Tool
GenericName[bg]=Инструмент за търсене
GenericName[bs]=Alat za pretraživanje
GenericName[ca]=Eina de cerca
GenericName[ca@valencia]=Eina de cerca
GenericName[da]=Søgeværktøj
GenericName[de]=Such-Werkzeug
GenericName[el]=Εργαλείο αναζήτησης
GenericName[en_GB]=Search Tool
GenericName[es]=Herramienta de búsqueda
GenericName[et]=Otsimise tööriist
GenericName[fi]=Hakutyökalu
GenericName[fr]=Outil de recherche
GenericName[ga]=Uirlis Chuardaigh
GenericName[gl]=Utilidade de procura
GenericName[hu]=Kereső eszköz
GenericName[it]=Strumento ricerca
GenericName[ja]=検索ツール
GenericName[kk]=Іздеу құралы
GenericName[nb]=Søkeverktøy
GenericName[nds]=Söökwarktüüch
GenericName[nl]=Hulpmiddel voor zoeken
GenericName[pl]=Narzędzie znajdywania
GenericName[pt]=Ferramenta de Pesquisa
GenericName[pt_BR]=Ferramenta de Pesquisa
GenericName[ru]=Средство поиска
GenericName[sk]=Nástroj na hľadanie
GenericName[sl]=Orodje za iskanje
GenericName[sv]=Sökverktyg
GenericName[tr]=Arama Aracı
GenericName[ug]=ئىزدەش قورالى
GenericName[uk]=Інструмент пошуку
GenericName[x-test]=xxSearch Toolxx
GenericName[zh_CN]=搜索工具
GenericName[zh_TW]=搜尋工具
Icon=kfind
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevgrepview
X-KDE-PluginInfo-Name=kdevgrepview
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/grepview/kdevgrepview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Allows fast searching of multiple files using patterns or regular expressions. And allow to replace it too.
Comment[bs]=Omogućava brzo pretraživanje više datoteka pomoću obrazaca i regularnim izrazima. I omogućava da ga zamjenu takođe.
Comment[ca]=Permet la cerca ràpida de múltiples fitxers usant patrons o expressions regulars. I també permet substitucions.
Comment[ca@valencia]=Permet la cerca ràpida de múltiples fitxers usant patrons o expressions regulars. I també permet substitucions.
Comment[da]=Muliggør hurtig søgning af flere filer med brug af mønstre eller regulære udtryk. Muliggør også erstatning.
Comment[de]=Ermöglicht es, Dateien mit Hilfe von Mustern und regulären Ausdrücken zu durchsuchen bzw. Ersetzungen vorzunehmen.
Comment[el]=Επιτρέπει γρήγορη αναζήτηση πολλών αρχείων με χρήση προτύπων ή κανονικών εκφράσεων. Επιτρέπει και την αντικατάστασή τους επίσης.
Comment[es]=Permite búsquedas rápidas de múltiples archivos usando patrones o expresiones regulares. También permite sustituciones.
Comment[et]=Lubab mustreid või regulaaravaldisi kasutades kiiresti paljudes failides teksti otsida, samuti asendada.
Comment[fi]=Mahdollistaa nopean useiden tiedostojen etsinnän käyttäen malleja tai säännöllisiä lausekkeita. Sallii myös korvauksen.
Comment[fr]=Permet la recherche rapide de fichiers multiples à l'aide de motifs ou d'expressions rationnelles, et d'effectuer le remplacement aussi.
Comment[ga]=Ceadaíonn sé duit il-comhaid a chuardach go tapa le patrúin nó sloinn ionadaíochta. Agus is féidir asáitiú chomh maith.
Comment[gl]=Permite facer unha procura rápida en varios ficheiros empregando padróns ou expresións regulares, e tamén realizar substitucións.
Comment[hu]=Lehetővé teszi több fájl gyors keresését minták és reguláris kifejezések használatával. És lehetővé teszi a cserét is.
Comment[it]=Consente la ricerca veloce di file multipli usando espressioni regolari o modelli. E consente anche di sostituirli.
Comment[kk]=Бірнеше файлда жәй не үлгі өрнегі бойынша тез іздеу мүмкіндігі. Қосымша ауыстыруға да болады.
Comment[nb]=Gjør raskt søk i flere filer mulig ved hjelp av mønstre eller regulære uttrykk. Og kan erstatte også.
Comment[nds]=Stellt gau Dörsöken vun mehr Dateien mit Söökmustern oder reguleer Utdrück praat. Utwesseln warrt ok ünnerstütt.
Comment[nl]=Staat toe snel te zoeken naar meerdere bestanden met gebruik van patronen of reguliere expressies. Staat ook vervanging toe.
Comment[pl]=Pozwala na szybkie znajdowanie wielu plików wykorzystując wzorce lub regularne wyrażenia. Pozwala także na ich zastępowanie.
Comment[pt]=Permite pesquisar rapidamente em vários ficheiros, usando padrões ou expressões regulares, permitindo também efectuar substituições.
Comment[pt_BR]=Permite pesquisar rapidamente em vários arquivos, usando padrões ou expressões regulares e também realizar substituições.
Comment[ru]=Позволяет быстро искать (и заменять) текст по множеству файлов, применяя шаблоны поиска или регулярные выражения.
Comment[sk]=Umožní rýchle hľadanie viacerých súborov pomocou vzorov alebo regulárnych výrazov a umožní ich nahradiť.
Comment[sl]=Omogoča hitro iskanje po več datotekah, z uporabo vzorcev ali pa logičnih izrazov. Omogoča tudi zamenjave.
Comment[sv]=Tillåter snabb sökning i flera filer med mönster eller reguljära uttryck, och tillåter dessutom ersättning.
Comment[tr]=Desenleri ve düzenli ifadeleri kullanarak, birçok dosyada hızlı bir şekilde arama yapılmasını sağlar. Bul değiştir işlevini de yapar.
Comment[ug]=ئەندىزە ياكى مۇنتىزىم ئىپادە ئارقىلىق نۇرغۇن ھۆججەتلەردىن ئىزدەش ۋە ئالماشتۇرۇشقا ئىجازەت بېرىدۇ.
Comment[uk]=Надає можливості швидкого пошуку та заміни у декількох файлів на основі шаблонів або формальних виразів.
Comment[x-test]=xxAllows fast searching of multiple files using patterns or regular expressions. And allow to replace it too.xx
Comment[zh_CN]=可以用模式或正则表达式快速搜索多个文件，还可以替换。
Comment[zh_TW]=允許使用樣式或正規表示式來快速搜尋與取代多個檔案。
Name=Find/Replace In Files
Name[bg]=Търсене и заместване във файлове
Name[bs]=Nađi/zamijeni u datotekama
Name[ca]=Cerca i substitució en fitxers
Name[ca@valencia]=Cerca i substitució en fitxers
Name[cs]=Hledat-nahradit v souborech
Name[da]=Find/erstat i filer
Name[de]=In Dateien suchen/ersetzen
Name[el]=Αναζήτηση/Αντικατάσταση σε αρχεία
Name[en_GB]=Find/Replace In Files
Name[es]=Buscar/sustituir en archivos
Name[et]=Failides otsimine ja asendamine
Name[fi]=Etsi ja korvaa tiedostoista
Name[fr]=Chercher / Remplacer dans les fichiers
Name[gl]=Procurar/Substituír nos ficheiros
Name[hu]=Keresés/csere fájlokban
Name[it]=Trova/Sostituisci nei file
Name[kk]=Файлдарда іздеу/ауыстыру
Name[nb]=Finn/erstatt i filer
Name[nds]=Söken un Utwesseln in Dateien
Name[nl]=Zoeken/vervangen in bestanden
Name[pl]=Znajdź/zastąp w plikach
Name[pt]=Procurar/Substituir nos Ficheiros
Name[pt_BR]=Procurar/Substituir nos arquivos
Name[ru]=Поиск/замена в файлах
Name[sk]=Hľadať/nahradiť v súboroch
Name[sl]=Najdi/zamenjaj v datotekah
Name[sv]=Sök eller ersätt i filer
Name[tr]=Bu Dosyalarda Bul ve Değiştir
Name[ug]=ھۆججەت ئىچىدىن ئىزدەش/ئالماشتۇرۇش
Name[uk]=Пошук або заміна у файлах
Name[x-test]=xxFind/Replace In Filesxx
Name[zh_CN]=在文件中查找/替换
Name[zh_TW]=在檔案中尋找/取代
GenericName=Search Tool
GenericName[bg]=Инструмент за търсене
GenericName[bs]=Alat za pretraživanje
GenericName[ca]=Eina de cerca
GenericName[ca@valencia]=Eina de cerca
GenericName[da]=Søgeværktøj
GenericName[de]=Such-Werkzeug
GenericName[el]=Εργαλείο αναζήτησης
GenericName[en_GB]=Search Tool
GenericName[es]=Herramienta de búsqueda
GenericName[et]=Otsimise tööriist
GenericName[fi]=Hakutyökalu
GenericName[fr]=Outil de recherche
GenericName[ga]=Uirlis Chuardaigh
GenericName[gl]=Utilidade de procura
GenericName[hu]=Kereső eszköz
GenericName[it]=Strumento ricerca
GenericName[ja]=検索ツール
GenericName[kk]=Іздеу құралы
GenericName[nb]=Søkeverktøy
GenericName[nds]=Söökwarktüüch
GenericName[nl]=Hulpmiddel voor zoeken
GenericName[pl]=Narzędzie znajdywania
GenericName[pt]=Ferramenta de Pesquisa
GenericName[pt_BR]=Ferramenta de Pesquisa
GenericName[ru]=Средство поиска
GenericName[sk]=Nástroj na hľadanie
GenericName[sl]=Orodje za iskanje
GenericName[sv]=Sökverktyg
GenericName[tr]=Arama Aracı
GenericName[ug]=ئىزدەش قورالى
GenericName[uk]=Інструмент пошуку
GenericName[x-test]=xxSearch Toolxx
GenericName[zh_CN]=搜索工具
GenericName[zh_TW]=搜尋工具
Icon=kfind
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevgrepview
X-KDE-PluginInfo-Name=kdevgrepview
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
